@@ -14,7 +14,7 @@ __author__ = (
     "Mark Harviston <mark.harviston@gmail.com>, "
     "Arve Knudsen <arve.knudsen@gmail.com>",
 )
-__version__ = "0.17.0"
+__version__ = "0.18.0"
 __url__ = "https://github.com/CabbageDevelopment/qasync"
 __license__ = "BSD"
 __all__ = ["QEventLoop", "QThreadExecutor", "asyncSlot", "asyncClose"]
@@ -460,7 +460,7 @@ class _QEventLoop:
         """Get time according to event loop's clock."""
         return time.monotonic()
 
-    def add_reader(self, fd, callback, *args):
+    def _add_reader(self, fd, callback, *args):
         """Register a callback for when a file descriptor is ready for reading."""
         self._check_closed()
 
@@ -484,7 +484,7 @@ class _QEventLoop:
         )
         self._read_notifiers[fd] = notifier
 
-    def remove_reader(self, fd):
+    def _remove_reader(self, fd):
         """Remove reader callback."""
         if self.is_closed():
             return
@@ -498,7 +498,7 @@ class _QEventLoop:
             notifier.setEnabled(False)
             return True
 
-    def add_writer(self, fd, callback, *args):
+    def _add_writer(self, fd, callback, *args):
         """Register a callback for when a file descriptor is ready for writing."""
         self._check_closed()
         try:
@@ -521,7 +521,7 @@ class _QEventLoop:
         )
         self._write_notifiers[fd] = notifier
 
-    def remove_writer(self, fd):
+    def _remove_writer(self, fd):
         """Remove writer callback."""
         if self.is_closed():
             return
