@@ -120,13 +120,13 @@ class _Selector(selectors.BaseSelector):
         return key
 
     def __on_read_activated(self, fd):
-        self._logger.debug('File {} ready to read'.format(fd))
+        self._logger.debug('File %s ready to read', fd)
         key = self._key_from_fd(fd)
         if key:
             self.__parent._process_event(key, EVENT_READ & key.events)
 
     def __on_write_activated(self, fd):
-        self._logger.debug('File {} ready to write'.format(fd))
+        self._logger.debug('File %s ready to write', fd)
         key = self._key_from_fd(fd)
         if key:
             self.__parent._process_event(key, EVENT_WRITE & key.events)
@@ -205,17 +205,17 @@ class _SelectorEventLoop(asyncio.SelectorEventLoop):
 
     def _process_event(self, key, mask):
         """Selector has delivered us an event."""
-        self._logger.debug('Processing event with key {} and mask {}'.format(key, mask))
+        self._logger.debug('Processing event with key %s and mask %s', key, mask)
         fileobj, (reader, writer) = key.fileobj, key.data
         if mask & selectors.EVENT_READ and reader is not None:
             if reader._cancelled:
                 self.remove_reader(fileobj)
             else:
-                self._logger.debug('Invoking reader callback: {}'.format(reader))
+                self._logger.debug('Invoking reader callback: %s', reader)
                 reader._run()
         if mask & selectors.EVENT_WRITE and writer is not None:
             if writer._cancelled:
                 self.remove_writer(fileobj)
             else:
-                self._logger.debug('Invoking writer callback: {}'.format(writer))
+                self._logger.debug('Invoking writer callback: %s', writer)
                 writer._run()
